@@ -7,15 +7,31 @@
 #' @export
 extract_numbers <- strex::str_extract_numbers
 
+#' @rdname extract_numbers
+#' @export
+str_extract_numbers <- extract_numbers
+
 #' @rdname extract_numbers
 #' @inheritParams strex::str_nth_number
 #' @export
 nth_number <- strex::str_nth_number
 
+#' @rdname extract_numbers
+#' @export
+str_nth_number <- nth_number
+
 #' @rdname extract_numbers
 #' @export
 first_number <- strex::str_first_number
 
+#' @rdname extract_numbers
+#' @export
+str_first_number <- first_number
+
 #' @rdname extract_numbers
 #' @export
 last_number <- strex::str_last_number
+
+#' @rdname extract_numbers
+#' @export
+str_last_number <- last_number
